Unit Conversion
===============

[![Build Status](https://travis-ci.org/mikecharles/cpc.units.svg?branch=master)](https://travis-ci.org/mikecharles/cpc.units) [![Coverage Status](https://coveralls.io/repos/github/mikecharles/cpc.geogrids/badge.svg?branch=master)](https://coveralls.io/github/mikecharles/cpc.geogrids?branch=master)

Installation
------------

You must have [Anaconda](https://anaconda.org) installed in order to install `cpc.geogrids`. Follow their instructions for installing on your system. Once you have Anaconda installed, installing `cpc.geogrids` is simple:

    $ make install

More documentation
------------------

Visit our [documentation site](https://mikecharles.github.io/cpc.units)

Contributing
------------

See our [CONTRIBUTING document](.github/CONTRIBUTING.md)
